<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:datetime="http://exslt.org/dates-and-times" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="datetime Lang" xmlns:XSLUtils="com.esko.webcenter.jsp.XSLUtils">
	<xsl:import href="templatedate.xsl"/>
	<xsl:import href="projmgmnttemplate.xsl"/>
	<xsl:import href="attrunittmplts.xsl"/>
	<xsl:import href="searchtemplate.xsl"/>
	<xsl:import href="wctasksearch_template.xsl"/>
    <xsl:import href="framework.xsl"/>
	<xsl:import href="searcherror_template.xsl"/>
	
	<xsl:variable name="useTableBodyContainer" select="false()" />
	
    <xsl:template name="bodyextensions">
	  <xsl:attribute name="onload"></xsl:attribute>
    </xsl:template>	

  <!-- Keys -->
  <xsl:key name="labelKey" match="/webcenter_page/search_criteria/saved_search_criteria/row/saved_search_criterion" use="@key"/>

  <!-- 
  
            template that is used to generate a link; overwrites the empty version in template.xsl
            
  -->
  <xsl:template name="detailsHref">
	<xsl:attribute name="href"><xsl:value-of select="normalize-space(url)"/></xsl:attribute>
  </xsl:template>

<!-- 
  
            template that generates the pagination component
                        
-->
<xsl:template name="SearchResultsPager">

  <xsl:variable name="resultCount" select="number(result_count)"/>
  <xsl:variable name="colsPerPage" select="number(cols_per_page)"/>
  <xsl:variable name="rowsPerPage" select="number(rows_per_page)"/>
  <xsl:variable name="resultsPerPage" select="number($rowsPerPage * $colsPerPage)"/>
  
  <!-- pagination logic (duplicated code, can be found in "SearchResultsPager" and "SourcePage*" templates) -->
  <xsl:variable name="firstIndex" select="number(start_search_id)"/>
  <xsl:variable name="pageCountMin">
  	<xsl:choose>
  		<xsl:when test="$resultCount=0">
  			<xsl:value-of select="1"/>
  		</xsl:when>
  		<xsl:otherwise>
  			<xsl:value-of select="ceiling($resultCount div $resultsPerPage)"/>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:variable>
  <xsl:variable name="pageCount">
  	<xsl:choose>
  		<xsl:when test="($firstIndex &gt; 1) and ($pageCountMin &lt; 2)">
   			<xsl:value-of select="2"/>
  		</xsl:when>
  		<xsl:otherwise>
   			<xsl:value-of select="$pageCountMin"/>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:variable>
  <xsl:variable name="curPageNumMin" select="ceiling($firstIndex div $resultsPerPage)"/>
  <xsl:variable name="curPageNum">
  	<xsl:choose>
  		<xsl:when test="($firstIndex &gt; 1) and ($curPageNumMin &lt; 2)">
   			<xsl:value-of select="2"/>
  		</xsl:when>
  		<xsl:otherwise>
   			<xsl:value-of select="$curPageNumMin"/>
  		</xsl:otherwise>
  	</xsl:choose>
  </xsl:variable>
  
  <div class="wcr-pager searchresultspagination"
  	data-pagecount="{$pageCount}"
  	data-curpage="{$curPageNum}"
  	data-resultsperpage="{$resultsPerPage}"
  	>
  	<xsl:if test="$pageCount &gt; 1 and $curPageNum &gt; 1">
  	  <!-- go to first page -->
  	  <span class="pager">
  	  	<a class="btn btn-default searchresultspagelink" data-gotopage="{1}" title="{Lang:getStr(&lk;, 'FIRST')}">
  	  	  <i class="icon-normal icon icon-WCR_Table-Page-First12"></i>
  	    </a>
  	  </span>
  	  <!-- go to previous page -->
  	  <span class="pager">
  	  	<a class="btn btn-default searchresultspagelink" data-gotopage="{$curPageNum - 1}" title="{Lang:getStr(&lk;,'PREVIOUS')}">
  	  	  <i class="icon-normal icon icon-WCR_Table-Page-Previous12"></i>
  	    </a>
  	  </span>
  	</xsl:if>
  	<span class="form-control">
 	  <!-- display Page X of N -->
      <xsl:value-of select="Lang:getStr(&lk;,'PAGE')"/><xsl:text> </xsl:text>
      <xsl:value-of select="$curPageNum"/><xsl:text> </xsl:text>
      <xsl:value-of select="Lang:getStr(&lk;,'OF')"/><xsl:text> </xsl:text>
      <xsl:value-of select="$pageCount"/>
  	</span>
  	<xsl:if test="$pageCount &gt; 1 and $curPageNum &lt; $pageCount">
  	  <!-- go to first page -->
  	  <span class="pager">
  	  	<a class="btn btn-default searchresultspagelink" data-gotopage="{$curPageNum +1}" title="{Lang:getStr(&lk;,'NEXT')}">
  	  	  <i class="icon-normal icon icon-WCR_Table-Page-Next12"></i>
  	    </a>
  	  </span>
  	  <!-- go to previous page -->
  	  <span class="pager">
  	  	<a class="btn btn-default searchresultspagelink" data-gotopage="{$pageCount}" title="{Lang:getStr(&lk;, 'LAST')}">
  	  	  <i class="icon-normal icon icon-WCR_Table-Page-Last12"></i>
  	    </a>
  	  </span>
  	</xsl:if>
  </div>
</xsl:template>

<!-- 

           template that generates the count "Found: x results"
           
           !! Needs to be on the page because also generates hidden input used by asset browser.

 -->
<xsl:template name="SearchResultsCountDisplay">

  <!-- vars... -->
  <xsl:variable name="resultCount" select="number(/webcenter_page/result_count)"/>
  <xsl:variable name="sectionID" select="/webcenter_page/hp_section_id"/>
  <xsl:variable name="hpPrefix">
	<xsl:choose>
		<xsl:when test="string-length($sectionID) = 0"><xsl:value-of select="''"/></xsl:when>
		<xsl:otherwise><xsl:value-of select="$sectionID"/><xsl:value-of select="'_'"/></xsl:otherwise>
	</xsl:choose>
  </xsl:variable>
  
  <!-- Found: x items. -->
  <xsl:choose>
	<xsl:when test="number($resultCount)=number(1)"> 
	  <xsl:value-of select="Lang:getStr(&lk;,'SEARCHCOUNTIS1')"/>&nbsp;
	</xsl:when>
	<xsl:otherwise>
	  <xsl:value-of select="Lang:getStr(&lk;,'SEARCHCOUNT_PART1')"/>&nbsp;<xsl:value-of select = "$resultCount"/>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'SEARCHCOUNT_PART2')"/>&nbsp;
	</xsl:otherwise>
  </xsl:choose>
</xsl:template>


<!-- 

           template that generates the result count as a badge

 -->
<xsl:template name="SearchResultsCountBadge">
	<xsl:variable name="resultCount" select="number(/webcenter_page/result_count)"/>
	<span class="badge"><xsl:value-of select = "$resultCount"/></span>
</xsl:template>

<!-- 

           template that generates the show/hide thumbnails button

 -->
<xsl:template name="SearchResultsShowHideThumbnailsButton">
	<xsl:variable name="showThumbnails" select="/webcenter_page/show_thumbnails"/>
	
	<xsl:if test="not(/webcenter_page/search_criteria/displayPreferences/chkbox_HideThumbnail='0')">
		<!-- the button -->
		<xsl:choose>
			<xsl:when test="number($showThumbnails)=number(1)">
				<a class="btn btn-default searchresultstoggledisplaystyle" data-goto="without-thumbs" title="{concat(Lang:getStr(&lk;,'HIDE'), ' ', Lang:getStr(&lk;,'THUMBNAILS'))}">	
					<i class="icon containerIcon icon-normal icon-WCR_Table-Thumb-Hide12-cont">
						<i class="icon subIcon icon-normal icon-WCR_Table-Thumb-Hide12-sub"></i>
					</i>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<a class="btn btn-default searchresultstoggledisplaystyle" data-goto="with-thumbs" title="{concat(Lang:getStr(&lk;,'SHOW'), ' ', Lang:getStr(&lk;,'THUMBNAILS'))}">
					<i class="icon icon-normal icon-WCR_Table-Thumb-Show12"></i>
				</a>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:if>
</xsl:template>

<!-- 

              template that generates the button(s) for changing the result style

 -->
<xsl:template name="SearchResultsToggleResultsStyleButton">
  <xsl:param name="supportsGridMode" select="true()"/>
  <xsl:param name="supportsCardMode" select="false()"/>
  
  <xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>

  <xsl:if test="($supportsGridMode or $supportsCardMode) and not(/webcenter_page/search_criteria/displayPreferences/chkbox_ShowGridList='0')" >
	  <div class="btn-group">
	  	<xsl:if test="not($resultsStyle='list')">
			<button class="btn btn-default searchresultstoggledisplaystyle" type="button" data-goto="list">
				<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'SHOW')"/><xsl:text>&nbsp;</xsl:text><xsl:value-of select="Lang:getStr(&lk;,'ASLIST')"/></xsl:attribute>
				<i class="icon icon-WCR_Table-View-List12"/>
			</button>
		</xsl:if>
		
		<xsl:if test="$supportsGridMode and not($resultsStyle='grid')">
			<button class="btn btn-default searchresultstoggledisplaystyle" type="button" data-goto="grid">
				<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'SHOW')"/><xsl:text>&nbsp;</xsl:text><xsl:value-of select="Lang:getStr(&lk;,'ASGRID')"/></xsl:attribute>
				<i class="icon icon-WCR_Table-View-Grid12"/>
			</button>
		</xsl:if>
		
		<xsl:if test="$supportsCardMode and not($resultsStyle='card')">
			<button class="btn btn-default searchresultstoggledisplaystyle" type="button" data-goto="card">
				<xsl:attribute name="title"><xsl:value-of select="Lang:getStr(&lk;,'SHOW')"/><xsl:text>&nbsp;</xsl:text><xsl:value-of select="Lang:getStr(&lk;,'ASCARD')"/></xsl:attribute>
				<i class="icon icon-WCR_Table-View-Card12"/>
			</button>
		</xsl:if>
	  </div>
  </xsl:if>
</xsl:template>

<xsl:template name="SearchResultsSortByDropdown">
	<div class="wcr-filter pull-right" style="margin:0px;">
    	<label><xsl:value-of select="Lang:getStr(&lk;,'SORT_BY')"/></label>
	   	<select class="form-control filter searchresultssortingdropdown">
	   	
	   		<!-- Allow sorting on name -->
			<option data-fieldId="db_name" data-order="asc">
				<xsl:if test="(key('sortingCriteriaKey', 'db_name_sort')/@number = '1') and 
							  (key('sortingCriteriaKey', 'db_name_sort')/@order = 'asc')">
				  <xsl:attribute name="selected">selected</xsl:attribute>			  
	    		</xsl:if>			
				<xsl:value-of select="Lang:getStr(&lk;,'NAME')"/>
			</option>
			<option data-fieldId="db_name" data-order="desc">
				<xsl:if test="(key('sortingCriteriaKey', 'db_name_sort')/@number = '1') and 
							  (key('sortingCriteriaKey', 'db_name_sort')/@order = 'desc')">
				  <xsl:attribute name="selected">selected</xsl:attribute>			  
	    		</xsl:if>			
				<xsl:value-of select="Lang:getStr(&lk;,'REVERSED')"/>&nbsp;<xsl:value-of select="Lang:getStr(&lk;,'NAME')"/>
			</option>
			
			<!-- Allow sorting on all other columns -->
			<xsl:for-each select="/webcenter_page/searchdata/columns/column">
				<xsl:sort data-type="number" order="ascending" select="@sequence"/>
				<xsl:variable name="fieldid" select="@id"/>
				
				<xsl:if test="@supportsSorting = '1'">	
					<option data-fieldId="{$fieldid}" data-order="asc">
						<xsl:if test="(@sort_number = '1') and (@sort_order = 'asc')">
					  	  <xsl:attribute name="selected">selected</xsl:attribute>			  
	    				</xsl:if>			
						<xsl:value-of select="@label"/>
					</option>
					<option data-fieldId="{$fieldid}" data-order="desc">
						<xsl:if test="(@sort_number = '1') and (@sort_order = 'desc')">
					  	  <xsl:attribute name="selected">selected</xsl:attribute>			  
	    				</xsl:if>			
						<xsl:value-of select="Lang:getStr(&lk;,'REVERSED')"/>&nbsp;<xsl:value-of select="@label"/>
					</option>					
			   </xsl:if>
			</xsl:for-each>
		</select>
	</div>
</xsl:template>
	
<xsl:template name="searchResultsHeaderGeneric">
	<xsl:param name="titleString"/>
	<xsl:param name="showSaveSearch"/>
	<xsl:param name="hpSectionId"/>
	
	<div class="page-header">
		<!-- header of search results -->
		<h1>
			<!-- the action buttons on the right side -->
			<div class="header-action-buttons">
				<xsl:if test="not(/webcenter_page/hideMenu)">	
					<!-- Clear Form link only required if we have search results parameters or an asset tree visible -->
					<xsl:if test="(/webcenter_page/search_criteria/displayPreferences/cascading_attribute_trees) or 
								  (/webcenter_page/search_criteria/saved_search_criteria/row/saved_search_criterion[@visibility!='Hidden'] )">
						<a class="btn btn-default action-searchresultsclearform" data-targetsection="{$hpSectionId}">
							<xsl:value-of select="Lang:getStr(&lk;,'CLEARSEARCH')"/>
						</a>
					</xsl:if>
				
					<!-- Save this search button -->
					<xsl:if test="($showSaveSearch='true') and not(/webcenter_page/search_criteria/displayPreferences/chkbox_SaveSearch='0') ">
						
						
						<!-- button -->
						<a class="btn btn-default" href="javascript:SaveSearch()">
							<xsl:value-of select="Lang:getStr(&lk;,'ADVSEARCH_SAVESEARCH')"/>					
						</a>
					</xsl:if>
					
					<xsl:if test= "not(/webcenter_page/search_criteria/displayPreferences/chkbox_SaveExcel='0')">
						<a class="btn btn-default" href="javascript:downloadsearchresult()">
							<xsl:value-of select="Lang:getStr(&lk;,'ADVSEARCH_SAVESEARCHRESULTS')" />
						</a>
					</xsl:if>
				</xsl:if>
			</div>
			
			<!-- 
				Forms form "Save Search" & "Save Search Results"
			 -->
			 
			 <!-- form which will be submitted for the "Save Search" action (after setting the type of search: document, project or task) -->
			<form name="savesearchform" action="dosavesearchactions.jsp" method="post" style="display:none;">
				<input type="hidden" name="actionVal" value=""/>
			</form>
			
			<!-- form which will be submitted for the "Save Search Results" action (after setting the type of search: document, project or task) -->
			<form name="downloadsearchform" action="dodownloadsearchresults.jsp" method="post" style="display:none;">
				<input type="hidden" name="actionVal" value="" />
				<input type="hidden" name="ssname">
					<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/saved_search_name" /></xsl:attribute>
				</input>
				<input type="hidden" name="sscope">
					<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/search_scope" /></xsl:attribute>
				</input>
			</form>
		
			<!-- the actual title -->
			<xsl:value-of select="$titleString"/>
			
			<span id="headerAssetViewDropdownContainer" class="headerAssetViewDropdownContainer">
				<!-- Place to put the dropdown for switching the asset browser view -->
				<!-- When this header is not available, the search page itself is used... -->
			</span>
		</h1>
	</div>
</xsl:template>

<!-- 
  
            template that shows search results header
            
-->
<xsl:template name="searchResultsHeader">

  <xsl:if test="count(/webcenter_page/hp_section_id)=0">
	<xsl:choose>
		<xsl:when test="count(/webcenter_page/saved_search_name_title)=1">
			<xsl:call-template name="searchResultsHeaderGeneric">
				<xsl:with-param name="titleString" select="/webcenter_page/saved_search_name_title"/>
				<xsl:with-param name="showSaveSearch" select="false()"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:when test="/webcenter_page/result_count=0">
			<xsl:call-template name="searchResultsHeaderGeneric">
				<xsl:with-param name="titleString" select="Lang:getStr(&lk;,'SEARCHRESULTS')"/>
				<xsl:with-param name="showSaveSearch" select="true()"/>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="searchResultsHeaderGeneric">
				<xsl:with-param name="titleString" select="Lang:getStr(&lk;,'SEARCHRESULTS')"/>
				<xsl:with-param name="showSaveSearch" select="true()"/>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
  </xsl:if>	
	
</xsl:template>

  <xsl:template name="searchNoResultsMessage">
  	<xsl:param name="error" select="error" />

	<div class="wcr-table no-margin">
		<div class="wcr-table-section">
			<div class="feedback-with-actions">
				<div class="feedback-actions">
					<p><xsl:value-of select="Lang:getStr(&lk;,'SEARCHNOITEMSFOUND')"/></p>
					
					<xsl:if test="string-length(/webcenter_page/hp_section_id)=0">
						<ul>
							<li><xsl:value-of select="Lang:getStr(&lk;,'SEARCH_ERROR_REFINE_PLAIN_TEXT')"/>&nbsp;<a  href="{searchPage}"><xsl:value-of select="Lang:getStr(&lk;,'SEARCH_ERROR_REFINE_HREF')"/></a>?</li>
							<li><xsl:value-of select="Lang:getStr(&lk;,'SEARCH_ERROR_RESTART_PLAIN_TEXT')"/>&nbsp;<a href="{searchPage}?action=Reset" ><xsl:value-of select="Lang:getStr(&lk;,'SEARCH_ERROR_RESTART_HREF')"/></a>?</li>
						</ul>
					</xsl:if>
				</div>
			</div>
		</div>
	</div>
  </xsl:template>

  
<!-- 
  
            template that controls display of numerator column
                        
--> <xsl:template name="NumerationColumn">
	<xsl:param name="numeration"/>
	<xsl:param name="showBorder" select="1"/>
    <td valign="middle" class="small_text_bold" align="center" >
		<!--
	<xsl:choose>
		<xsl:when test="$showBorder=1">
		  <xsl:attribute name="class">td_small_bold</xsl:attribute></xsl:when>		
		<xsl:otherwise><xsl:attribute name="class">td_small_bold_noborder</xsl:attribute></xsl:otherwise>
	</xsl:choose>
	-->
	<table border="0" cellspacing="0" cellpadding="0">
			<tr><td><img border="0" src="images/clearpixel.gif" alt="" width="1" height="5"/></td></tr>
			<tr><td class="small_text_bold" valign="middle"><xsl:value-of select = "$numeration"/>.</td></tr>
			<tr><td><img border="0" src="images/clearpixel.gif" alt="" width="1" height="5"/></td></tr>
		</table>
	</td>
 </xsl:template>		
  
<!-- 
  
            template that controls display of numerator header
                        
--> 
<xsl:template name="NumerationHeader">		
	  <th class="small_text_bold" align="center" valign="middle">#</th> 
 </xsl:template>	

 <!-- Header for Project Grid View  in case of user is not admin -->
 <xsl:template name="NumerationHeaderProjectGrid">		
	  <th class="lastHeaderCol" align="left" valign="middle"><!-- # --></th> 
 </xsl:template>	
 
 <xsl:template name="ThumbnailNameHeader">	
	<xsl:param name="showThumbnails"/>
	<xsl:param name="columnName" select="'db_name'"/>
  	<xsl:param name="langKey" select="'NAME'"/>
	
	<th align="left" data-columnid="{$columnName}">
 		<xsl:call-template name="addSearchResultsColumnSortingAttributes">
	   		<xsl:with-param name="columnName" select="$columnName"/>
	   		<xsl:with-param name="additionalClasses" select="'nobr'"/>
   		</xsl:call-template>
		<xsl:if test="$showThumbnails = 1">
			<xsl:attribute name="colspan">2</xsl:attribute>
		</xsl:if>
		
		<xsl:choose>
			<xsl:when test="key('labelKey',$columnName)/label"> 
				<xsl:value-of select="key('labelKey',$columnName)/label"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Lang:getStr(&lk;,$langKey)"/>
			</xsl:otherwise>
		</xsl:choose>
		
		<xsl:text> </xsl:text><xsl:call-template name="SearchResultsCountBadge"></xsl:call-template><i class="icon-sorting"/>
	  </th>
 </xsl:template>

		
<!-- Template for the parametric saved search parameters -->
<xsl:template name="searchResultsSavedSearchParms">
	
	<xsl:variable name="hpSectionId" select="/webcenter_page/hp_section_id"/>
	<xsl:variable name="hpPrefix">
	  <xsl:choose>
	    <xsl:when test="string-length($hpSectionId) = 0"><xsl:value-of select="''"/></xsl:when>
	    <xsl:otherwise><xsl:value-of select="$hpSectionId"/><xsl:value-of select="'_'"/></xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

    <div class="outerTdSearchParamsForm" style="display: none;">    

	  <xsl:variable name="actionURL" select="/webcenter_page/searchdata/saved_search_re_run_url" />
      <!-- Saved Search parameters panel -->
      <form method="post" name="advancedsearchform" id="advancedsearchform" action="{$actionURL}"  >
      	<xsl:attribute name="onsubmit">javascript:{searchAutoReRun('<xsl:value-of select="$hpSectionId"/>');return false;}</xsl:attribute>
	    
	    <input value="executeSavedSearchWithParms" name="actionVal" type="hidden" />
  	    
  	    <!-- copy the context to execute the saved Search in -->
  	    <xsl:if test="/webcenter_page/search_context/project_context">
	  	    <input name="projectID" type="hidden">
	  	    	<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/search_context/project_context"/></xsl:attribute>
	  	    	<xsl:attribute name="id"><xsl:value-of select="$hpSectionId"/>_projectID</xsl:attribute>
	  	    </input>
  	    </xsl:if>
  	    <xsl:if test="/webcenter_page/search_context/docversion_context">
	  	    <input name="docVerID" type="hidden">
	  	    	<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/search_context/docversion_context"/></xsl:attribute>
	  	    	<xsl:attribute name="id"><xsl:value-of select="$hpSectionId"/>_docVerID</xsl:attribute>
	  	    </input>
  	    </xsl:if>
  	    <xsl:if test="/webcenter_page/search_context/staticsmartnames_context">
  	    	<input name="staticSmartNames" type="hidden">
	  	    	<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/search_context/staticsmartnames_context"/></xsl:attribute>
	  	    	<xsl:attribute name="id"><xsl:value-of select="$hpSectionId"/>_staticSmartNames</xsl:attribute>
	  	    </input>
  	    </xsl:if>
		
		<!-- wrapper which adds scrollbars -->
		<div class="designpanelwrapper"  
			data-init="component/table/DropdownOverflowUtil" data-overflownamespace="wcr-search">
			
		    <table id="parmsTable" class="designpaneltable">    
			 	<tbody class="designpanelsection">
			 		
			 		<!-- HERE WE WILL PUT THE DESIGN PANEL -->
			 		
			 	</tbody>
	        </table>
        </div>
        
        <table class="searchbuttontable">
          <tr>
          	
            <!-- HERE we will put the "Search button" cell -->
            
			<!-- HERE we will put the "Available dropdown" cell -->
			
          </tr>
        </table>
        
      </form>
  	</div>

</xsl:template>
	
	<!-- 
            template that generates saved search parameter
	-->
 	<xsl:template name="savedSearchParam">
		<xsl:param name="ampersand" select="'&amp;'"/>
		<xsl:choose>
			<xsl:when test="count(/webcenter_page/saved_search_name)=1"><xsl:value-of select="$ampersand"/>searchName=<xsl:value-of select="XSLUtils:urlEncode(/webcenter_page/saved_search_name)"/></xsl:when>
			<xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

<!-- this template modifies an input string (actionURL) in the following way
	1. it searches for [str1], when this is found, it replaced [str1] by objectID
		Doing so, addnewdocument.jsp?projectID=[projectID] will result in 
				addnewdocument.jsp?projectID=<projectID>
	2. a) when not found, it appends ? to the url when there is no ? character in the actionURL,
		otherwise, it appends & to the input string
	2 b) it appends str1 = objectID to the actionURL
		this way, we obtain that xxx.jsp converts to xxx.jsp?project=<projectID>
						
 -->
<xsl:template name="constructActionURL">
		<xsl:param name="actionURL"/>
		<xsl:param name="str1"/>
		<xsl:param name="objectID"/>
		
		<xsl:variable name="smartName"><xsl:value-of select="'['"/><xsl:value-of select="$str1"/><xsl:value-of select="']'"/></xsl:variable>

		<xsl:choose>
			<xsl:when test="contains($actionURL,$smartName)">
				<xsl:call-template name="replaceSubString">
					<xsl:with-param name="sourceString" select="$actionURL"/>
					<xsl:with-param name="str1" select="$smartName"/>
					<xsl:with-param name="str2" select="$objectID"/>								
				</xsl:call-template>				
			</xsl:when>
			<xsl:when test="contains($actionURL,'?')">
				<xsl:value-of select="$actionURL"/>&amp;<xsl:value-of select="$str1"/><xsl:value-of select="'='"/><xsl:value-of select="$objectID"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$actionURL"/>?<xsl:value-of select="$str1"/><xsl:value-of select="'='"/><xsl:value-of select="$objectID"/>				
			</xsl:otherwise>
		</xsl:choose>

</xsl:template>


	<!-- 
            template that generates a name extesion for sections
	-->
	<xsl:template name="sectionNameExtension">
		<xsl:choose>
			<xsl:when test="(string-length(/webcenter_page/hp_section_id)>0)">_<xsl:value-of select="/webcenter_page/hp_section_id"/></xsl:when>
		    <xsl:otherwise></xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- 
            template that generates the menu name to be used on the page			
	-->
	<xsl:template name="menuName">menu<xsl:call-template name="sectionNameExtension"/></xsl:template>

	<!-- 
            template that generates the action form name to be used on the page			
	-->
	<xsl:template name="actionFormName">actionform<xsl:call-template name="sectionNameExtension"/></xsl:template>
  
  
  <!-- Used in List Search Results to make a cell for the header of one of the columns in the table -->
  <xsl:template name="SearchResultsColumnHeader">
  	<xsl:param name="columninfo"/>
  	
  	<xsl:variable name="fieldid" select="$columninfo/@id"/>
	<xsl:variable name="unitlabel">
		<!-- the unit label -->
		<xsl:if test="$columninfo/@unitkey"><xsl:value-of select="Lang:getStrFallback(&lk;, $columninfo/@unitkey, $columninfo/@unitkey)" /></xsl:if>
	</xsl:variable>
	
	<th data-columnid="{$fieldid}">
	    <xsl:attribute name="class">nobr <xsl:value-of select="$columninfo/@typeclass"/><xsl:text> </xsl:text>
	    	<xsl:if test="$columninfo/@supportsSorting='1'"><xsl:text>column-sort </xsl:text>
		   	  <xsl:choose>
			     <xsl:when test="@sort_number = '1'">
			       <xsl:choose>
			          <xsl:when test="@sort_order = 'asc'">sort-asc</xsl:when>
					  <xsl:otherwise>sort-desc</xsl:otherwise>
					</xsl:choose>	       
			      </xsl:when>
			      <xsl:otherwise>sort-available</xsl:otherwise>
			  </xsl:choose>
		    </xsl:if>
	    </xsl:attribute>
  	  	
  	  	<!-- column name -->
  	  	<xsl:value-of select="$columninfo/@label"/>
		
		<!-- unit -->
		<xsl:if test="string-length($unitlabel) > 0"><xsl:text> </xsl:text><small><xsl:text>[</xsl:text><xsl:value-of select="$unitlabel"/><xsl:text>]</xsl:text></small></xsl:if>
		
		<!-- editable button -->
		<xsl:if test="$columninfo/@editbuttonenabled = '1'">
			<a class="searchheadereditbutton" data-jsonoptions="{$columninfo/@editbuttonconfig}" id="change_{$fieldid}">
				<i class="icon icon-WCR_Actions-AR-Editor12"></i>
			</a>
		</xsl:if>
		
		<!-- sorting arrow -->
		<xsl:if test="$columninfo/@supportsSorting='1'">
			<i class="icon-sorting"/>
		</xsl:if>
	</th>
  </xsl:template>

  
   <xsl:template name="SearchResultsCell">
	  	<xsl:param name="id"/>
  		<xsl:param name="typeclass"/>
  	
    <!-- Display using javascript... -->
    <td style="padding:2pt 5pt 2pt 5pt" class="{$typeclass}">
	    <div class="datacell" data-fieldid="{$id}">
	          <!-- the content will be put here... -->
	    </div>
    </td>
  	
  </xsl:template>
  
  <xsl:template name="addSearchResultsColumnSortingAttributes">
  	<xsl:param name="columnName"/>
  	<xsl:param name="supportsSorting" select="true()"/>
  	<xsl:param name="additionalClasses" select="''"/>
  	
  	<xsl:variable name="sortKey">
      <xsl:value-of select="$columnName"/>
      <xsl:value-of select="'_sort'"/>
    </xsl:variable>
    
    <xsl:attribute name="class"><xsl:value-of select="$additionalClasses"/><xsl:text> </xsl:text>
    	<xsl:if test="$supportsSorting='1'"><xsl:text>column-sort </xsl:text>
	    	<xsl:choose>
		       <xsl:when test="key('sortingCriteriaKey', $sortKey)/@number = '1'">
		    	<xsl:choose>
		          <xsl:when test="key('sortingCriteriaKey', $sortKey)/@order = 'asc'">
		          	<xsl:text>sort-asc</xsl:text>
				  </xsl:when>
				  <xsl:otherwise>
				  	<xsl:text>sort-desc</xsl:text>
				  </xsl:otherwise>
				</xsl:choose>	       
		      </xsl:when>
		      <xsl:otherwise>
		      	<xsl:text>sort-available</xsl:text>
		      </xsl:otherwise>
		    </xsl:choose>
	    </xsl:if>
    </xsl:attribute>
  </xsl:template>

  
  <xsl:template name="searchResultsGridLabel">
  	<xsl:param name="columnName"/>
  	<xsl:param name="langKey"/>
  	<xsl:param name="fullString"/>

    <xsl:if test="not(/webcenter_page/search_criteria/displayPreferences/chkbox_ShowLabels='0')"> 
  	
	  	<xsl:variable name="label">
	      <xsl:choose>
			<xsl:when test="$fullString">
				<xsl:value-of select="$fullString"/>
			</xsl:when>
			<xsl:when test="key('labelKey',$columnName)/label"> 
				<xsl:value-of select="key('labelKey',$columnName)/label"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="Lang:getStr(&lk;,$langKey)"/>
			</xsl:otherwise>
		  </xsl:choose>:
		</xsl:variable>
		
		<xsl:choose>
		  <xsl:when test="/webcenter_page/search_criteria/displayPreferences/chkbox_BoldLabels='1'"> 
		    <b><xsl:value-of select="$label"/></b>
		  </xsl:when>
		  <xsl:otherwise>
			<xsl:value-of select="$label"/>
		  </xsl:otherwise>
		</xsl:choose>

	</xsl:if>
	
  </xsl:template>

	<xsl:template name="scriptincs_search_results">

      <script type="text/javascript" src="javascript/webcenter_xml.js"/>   
   	  <script type="text/javascript" src="javascript/vector.js"/> 
	  <script type="text/javascript" src="javascript/dynamic_homepage_utils.js"/>
	  <script type="text/javascript" src="javascript/modalpopup.js"/>
	  <script type="text/javascript" src="javascript/ManageRoles.js"/>
	  <script src="javascript/search.js" type="text/javascript"/>
	  
	  <!-- for date picker -->
	  <xsl:call-template name="jqueryUIScriptImports"/>
	  
	  <xsl:call-template name="ResultsSortingJavaScript"/>
	  <xsl:call-template name="DateSearchJavaScript"/>
	  <xsl:call-template name="sDropEnabler" />
	  
 	  <script type="text/javascript">
	  	<xsl:call-template name="SearchResultsCommonFunctions"/>
        <xsl:call-template name="SearchCommonLangArr"/>
	  </script>

    </xsl:template>

 	<xsl:template name="SearchResultsCommonFunctions">
		   	
		function gatherURLParameters_<xsl:value-of select="/webcenter_page/hp_section_id"/>(paramsContainer)
   		{
	   		defaultURLParameters_<xsl:value-of select="/webcenter_page/hp_section_id"/>(paramsContainer);
	   		var paramFormElem = document.getElementById('<xsl:value-of select="/webcenter_page/hp_section_id"/>_display_params_form');
	   		//get parameters and add it to the container
	   		paramsContainer.addParameter(createStringURLParameterFromInputElement(paramFormElem.StartIndex));
	   		paramsContainer.addParameter(createStringURLParameterFromInputElement(paramFormElem.EndIndex));
   		}	

	   	function defaultURLParameters_<xsl:value-of select="/webcenter_page/hp_section_id"/>(paramsContainer)
	   	{
	   		var paramFormElem = document.getElementById('<xsl:value-of select="/webcenter_page/hp_section_id"/>_display_params_form');
	   		//get parameters and add it to the container
	   		paramsContainer.addParameter(createStringURLParameterFromInputElement(paramFormElem.showThumbnails));
	   		paramsContainer.addParameter(createStringURLParameterFromInputElement(paramFormElem.resultsStyle));
	   	}
		
		  function submitdownloadsearchresult(action)
          {
            document.downloadsearchform.actionVal.value = action;
            // post the request&#xA;
            document.downloadsearchform.submit();
          }
		 
 	</xsl:template>
 
 	<xsl:template name="SearchResultsStoredValues">
		<!-- If it's a search re-run we don't want a duplicate section on the page -->
 		<xsl:if test="count(/webcenter_page/search_re_run)=0">  
			<xsl:variable name="showThumbnails" select="/webcenter_page/show_thumbnails"/>
			<xsl:variable name="resultsStyle" select="/webcenter_page/results_style"/>
			<xsl:variable name="startIndex" select="number(/webcenter_page/start_search_id)"/>
			<xsl:variable name="endIndex" select="number(/webcenter_page/rows_per_page)*number(/webcenter_page/cols_per_page)"/>		
	
			<form style="margin: 0px; padding: 0px;">
				<xsl:attribute name="name"><xsl:value-of select="/webcenter_page/hp_section_id"/>_display_params_form</xsl:attribute>
				<xsl:attribute name="id"><xsl:value-of select="/webcenter_page/hp_section_id"/>_display_params_form</xsl:attribute>
				<input type="hidden" name="showThumbnails">
					<xsl:attribute name="value"><xsl:value-of select="$showThumbnails"/></xsl:attribute>
				</input>
				<input type="hidden" name="resultsStyle">
					<xsl:attribute name="value"><xsl:value-of select="$resultsStyle"/></xsl:attribute>
				</input>
				<input type="hidden" name="StartIndex">
					<xsl:attribute name="value"><xsl:value-of select="$startIndex"/></xsl:attribute>
				</input>
				<input type="hidden" name="EndIndex">
					<xsl:attribute name="value"><xsl:value-of select="$endIndex"/></xsl:attribute>
				</input>
				<input type="hidden" name="ssname">
					<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/saved_search_name" /></xsl:attribute>
				</input>
				<input type="hidden" name="sscope">
					<xsl:attribute name="value"><xsl:value-of select="/webcenter_page/search_scope" /></xsl:attribute>
				</input>
				<xsl:variable name="pageSize" select="number(/webcenter_page/rows_per_page)*number(/webcenter_page/cols_per_page)"/>
				<input type="hidden" name="pageSize"> 
					<xsl:attribute name="value"><xsl:value-of select="$pageSize"/></xsl:attribute>
				</input>
			</form> 
		</xsl:if>
	</xsl:template>
    
  	<!-- 
      template with inline javascript for both home_page section and normal results page
      called from scriptincs_hp_section
	-->
	<xsl:template name="scriptincs_common"/>

  	<!-- 
  
            template with inline javascript for home_page section
            called from framework.xsl
            calls scriptincs_common
            
	-->		
			
	<xsl:template name="scriptincs_hp_section">	

		<script type="text/javascript">	
			<xsl:if test="count(/webcenter_page/hp_section_id)=1">
				<xsl:attribute name="id"><xsl:value-of select="/webcenter_page/hp_section_id"/>_section_script</xsl:attribute>
			</xsl:if>

			<xsl:call-template name="scriptincs_common"/>
			<xsl:call-template name="RoleSearchLangArr"/>
			<xsl:call-template name="SearchResultsCommonFunctions"/>
			<xsl:call-template name="SearchCommonLangArr"/>
		</script>

	</xsl:template>
 
 
	<xsl:template name="SearchLangArr">
	  // construct the language array
	  if (typeof window.langArr == "undefined" || window.langArr === null){
	  	window.langArr = {};
	  }
	  <xsl:call-template name="i18n">
           <xsl:with-param name="keys">
              SEARCH_RESULTS_LOADING_FAILED|
              PERM_ERR_DOWNLOAD_DOC_VER|PERM_ERR_CHECKOUT_DOC_VER|PERM_ERR_NEW_DOC_VERSION|
              PERM_ERR_UPDATE_DOC_VER|PERM_ERR_DELETE_DOC_VER|PERM_ERR_RENAME_DOC_VER|
              AJAX_ERROR_NO_SESSION_TAG|CHECKED_OUT_DOWNLOAD_WARNING|CONFIRMDELDOCS|
              CONFIRMDELAPPONGDOCS
           </xsl:with-param>
           <xsl:with-param name="nested" select="1" />
           <xsl:with-param name="langVar" select="'langArr'"/>
       </xsl:call-template>

	</xsl:template>
	
	
	
	<xsl:template name="RoleSearchLangArr">
	  // construct the language array
	  if(window.i18n === undefined){
	  	window.i18n = {};
	  }
	  <xsl:call-template name="i18n">
          <xsl:with-param name="keys">
             USER|GROUP|FILTER_MYTASKS|FILTER_NONE|FILTER_MYGROUPS|INTEGERRESTRICTIONERROR|
             ADVSEARCH_VISIBILITY_HIDDEN|ADVSEARCH_VISIBILITY_AVAILABLE|ADVSEARCH_VISIBILITY_VISIBLE
          </xsl:with-param>
          <xsl:with-param name="nested" select="1" />
          <xsl:with-param name="langVar" select="'i18n'"/>
      </xsl:call-template>
</xsl:template>

	<!-- Get action menu tags from the search setup. If nothing is stored "default" is returned. -->
	<xsl:template name="GetActionMenuTagsFromSearch">
		<xsl:choose>
			<xsl:when test="/webcenter_page/search_criteria/displayPreferences/selectCustomActionsTags">
				<xsl:value-of select="/webcenter_page/search_criteria/displayPreferences/selectCustomActionsTags"/>
			</xsl:when>
			<xsl:otherwise><xsl:text>default</xsl:text></xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<xsl:template name="isInDrilldown">
		<xsl:variable name="hpSectionId" select="/webcenter_page/hp_section_id"/>
		<xsl:value-of select="starts-with($hpSectionId, '00004_')"/>
	</xsl:template>
	
	<xsl:variable name="isInDrilldown">
		<xsl:call-template name="isInDrilldown" />
	</xsl:variable>
	
	<xsl:template name="isStickyActions">
		<xsl:value-of select="not($isInDrilldown = 'true')" />
	</xsl:template>
	
	
	<xsl:template name="withShowHideThumbnailsButton">
		<xsl:value-of select="not($isInDrilldown = 'true')" />
	</xsl:template>
     
</xsl:stylesheet>
